# -*- coding: utf-8 -*-

import os
import sys
import logging
from logging.handlers import RotatingFileHandler

from cmutils.config_loaders import IniConfigLoader
from dropshipping.utils.offer_services import EsOfferService
from em_tasks.utils.product_service import ProductService
from em_tasks.store.models import init_store
from em_celery.utils.telegram_bot import TelegramBot


logger = logging.getLogger('em_celery.' + __name__)
formatter = logging.Formatter('%(asctime)s [%(levelname)s]: %(message)s')
logger.setLevel(logging.DEBUG)
stream_handler = logging.StreamHandler(sys.stdout)
stream_handler.setFormatter(formatter)
logger.addHandler(stream_handler)

_cfg = None

def get_config():
  global _cfg
  if _cfg is None:
    config_path = os.getenv(
      'MWS_COLLECTOR_CONFIGURATION_PATH',
      os.path.join('~', '.em_celery', 'config.ini'))
    config = IniConfigLoader(config_path)
    _cfg = config.load()

  return _cfg

def get_product_service():
  config = get_config()
  product_cfg = config['product_service']
  return ProductService(
    product_cfg['host'], product_cfg['port'], product_cfg['user'], product_cfg['password'])

def get_offer_service():
  config = get_config()
  offer_cfg = config['offer_service']
  return EsOfferService(
    offer_cfg['host'], offer_cfg['port'], offer_cfg['user'], offer_cfg['password'])

def get_offer_service_config():
  config = get_config()
  return config['offer_service']

def get_amz_offer_filter_config():
  filter_cond = {
    'rating': 60,
    'feedback': 5,
    'domestic': True,
    'shipping_time': 7,
    'subcondition': 70,
    'expire_hour': 1200,
  }

  config = get_config()
  amz_offer_filter_cfg = config.get('amz.offer.filter', None)
  if amz_offer_filter_cfg:
    filter_cond = {
      'rating': amz_offer_filter_cfg.get('rating', 60),
      'feedback': amz_offer_filter_cfg.get('feedback', 5),
      'domestic': amz_offer_filter_cfg.get('domestic', True),
      'shipping_time': amz_offer_filter_cfg.get('shipping_time', 7),
      'subcondition': amz_offer_filter_cfg.get('subcondition', 70),
      'expire_hour': amz_offer_filter_cfg.get('rating', 1200),
    }

  return filter_cond

def init_db():
  config = get_config()
  db = config['store_db']
  init_store(db['host'], db['user'], db['password'], db['name'])

def get_bot():
  return TelegramBot('6140656516:AAFRUeY4muuiIQ8uYndAB_EYUnnMescLWKU')
