# -*- coding: utf-8 -*-

import json

from em_tasks.tasks.spapi_fetch_products_task import SpapiFetchProductsTask
from sp_api.base.exceptions import (
  SellingApiForbiddenException,
  SellingApiException
)

from celery.exceptions import Ignore
from celery.exceptions import Reject
from celery.utils.log import get_task_logger

from em_celery.tasks.base import BaseTask
from em_celery.worker import app

logger = get_task_logger(__name__)


@app.task(base=BaseTask, bind=True, acks_late=True, rate_limit='6/m')
def spapi_fetch_products_task(self, marketplace, asins, condition='new'):
  task = SpapiFetchProductsTask(
    self.spapi, self.offer_service, self.product_service, marketplace, asins, condition)
  try:
    task.run()
  except SellingApiForbiddenException as e:
    logger.exception(e)
    app.control.broadcast('shutdown', destination=[self.request.hostname])
    self.bot.send_message(
      self.group_chat_id,
      "[SellingApiForbidden] Host: {}\n".format(self.request.hostname)
    )
    raise Reject(str(e), requeue=True)
  except Exception as e:
    logger.exception(e)
    raise Ignore()
