# -*- coding: utf-8 -*-

import json

import click

from em_tasks.store.store_util import StoreUtil
from em_tasks.tools.sheet_blacklist_keywords_syncer import SheetBlacklistKeywordsSyncer
from em_tasks.store.models import *

from em_celery import logger, init_db


@click.command('Sync blacklist keywords from Google Sheet to Local.')
@click.option('-s', '--store_code', required=True, type=str, help='Store code.')
@click.option('-sid', '--spreadsheet_id', required=True, type=str)
def sync_blacklist_keywords(store_code, spreadsheet_id):
  init_db()

  store = StoreUtil.get_store_by_code(store_code)
  if not store:
    logger.warning('[StoreNotFound] %s', store_code)
    return

  service_account_data = json.loads(store.service_account_data)
  syncer = SheetBlacklistKeywordsSyncer(service_account_data, spreadsheet_id)
  syncer.run()


if __name__ == "__main__":
  sync_blacklist_keywords()
