# -*- coding: utf-8 -*-

import json

import click

from em_tasks.store.store_util import StoreUtil
from em_tasks.tools.shopify_orders_sheet_importer import ShopifyOrdersSheetImporter
from em_tasks.store.models import *

from em_celery import logger, init_db


@click.command('Capture fulfillable Orders')
@click.option('-s', '--store_code', required=True, type=str, help='Store code.')
@click.option('-sids', '--spreadsheet_ids', type=str, default='', help='Spreadsheets to process.')
@click.option('-d', '--days', type=int, default=7, help='Days of sheets to process.')
def import_orders(store_code, spreadsheet_ids='', days=7):
  init_db()

  if spreadsheet_ids:
    spreadsheet_ids = spreadsheet_ids.split(',')
  else:
    spreadsheet_ids = [
      '1ZtOnb1fnmCT8pEg58WXmV0QlTb1VJYA8JVVzTJgyTFc',
      '1-tSAKaS8KeIWf_TZcGEcc7T49JU9jWXm2HL2O3HTthw',
      '1r_h4iU1iRovGG2XB9VIiQejtSY7O8nMdfro9jAvX1sU',
      '1gIC4wB4U8Nwz945Oi6ed53zbtANH1hiIYzbXt-2U5NM',
      '1zw7xzh1co7Gbgz1-eaoRCphp_bvZjb6PtqxaKSU96UI',
      '1TrUL9MUwjHaR-h4yIG6VCbIlaK87FZP08lijhxVELeM',
      '1JyfmUPR4BIQXYwpPtNjFkAr9ac4kajak82CJHiq54dE',
      '1sgwjRuw9ASeY6KDS94Xc4ke346mzN-welNHZS_au0bE',
    ]

  store = StoreUtil.get_store_by_code(store_code)
  if not store:
    logger.warning('[StoreNotFound] %s', store_code)
    return

  service_account_data = json.loads(store.service_account_data)
  importer = ShopifyOrdersSheetImporter(service_account_data, spreadsheet_ids, days)
  importer.run()

if __name__ == "__main__":
  import_orders()
