# -*- coding: utf-8 -*-

import json

import click

from em_celery import logger, init_db
from em_tasks.store.store_util import StoreUtil
from em_tasks.tools.shopify_orders_sheet_updater import ShopifyOrdersSheetUpdater
from em_tasks.store.models import *


@click.command('Update Orders that exported to Google Sheet')
@click.option('-s', '--store_code', required=True, type=str, help='Store code.')
@click.option('-d', '--days', type=int, default=7)
def update_orders(store_code, days=7):
  init_db()

  store = StoreUtil.get_store_by_code(store_code)
  if not store:
    logger.warning('[StoreNotFound] %s', store_code)
    return

  if not store.service_account_data:
    logger.warning('[StoreNoSheetCredentials] %s', store_code)
    return

  service_account_data = json.loads(store.service_account_data)
  credential = json.loads(store.api_credential)
  updater = ShopifyOrdersSheetUpdater(credential, service_account_data, days)
  updater.run()


if __name__ == "__main__":
  update_orders()
