# -*- coding: utf-8 -*-

import datetime
import json

import click

from em_celery import logger, init_db
from em_tasks.store.store_util import StoreUtil
from em_tasks.shopify.order_util import OrderUtil
from em_tasks.store.models import *


@click.command('Import Orders')
@click.option('-s', '--store_code', required=True, type=str, help='Store code.')
@click.option('-d', '--days', type=int, default=7, help='Sync how many days order, default is 7.')
def import_orders(store_code, days=7):
  init_db()

  store = StoreUtil.get_store_by_code(store_code)
  if not store:
    logger.warning('[StoreNotFound] %s', store_code)
    return

  credential = json.loads(store.api_credential)
  order_util = OrderUtil(credential['name'], credential['token'], credential.get('release', None))

  today = datetime.datetime.utcnow()
  from_date = today - datetime.timedelta(days=days)
  from_date_s = from_date.replace(microsecond=0).isoformat()
  order_util.import_orders({'processed_at_min': from_date_s})


if __name__ == "__main__":
  import_orders()
