# -*- coding: utf-8 -*-

import json

import click

from em_celery import logger, init_db
from em_tasks.store.store_util import StoreUtil
from em_tasks.tools.shopify_orders_sheet_exporter import ShopifyOrdersSheetExporter
from em_tasks.store.models import *


@click.command('Export Order to Google Sheet')
@click.option('-s', '--store_code', required=True, type=str, help='Store code.')
def export_orders(store_code):
  init_db()

  store = StoreUtil.get_store_by_code(store_code)
  if not store:
    logger.warning('[StoreNotFound] %s', store_code)
    return

  if not store.service_account_data:
    logger.warning('[StoreNoSheetCredentials] %s', store_code)
    return

  service_account_data = json.loads(store.service_account_data)
  exporter = ShopifyOrdersSheetExporter(service_account_data)
  exporter.run()


if __name__ == "__main__":
  export_orders()
